@@ -12,6 +12,7 @@ from .db_utils import MongoClient
 from .db_utils import Motor
 from .db_utils import MotorClient
 from .db_utils import Mysql
+from .db_utils import parse_uri
 from .db_utils import Redis
 from .decorator import aioretry
 from .decorator import retry
@@ -60,7 +61,7 @@ warnings.filterwarnings("ignore")
 __all__ = [
     'awaitable', 'floor', 'ceil', 'to_str', 'to_bytes', 'tqdm', 'yaml_load', 'yaml_dump',
     'timeit', 'retry', 'aioretry', 'smart_decorator', 'synchronize', 'cached_property',
-    'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool',
+    'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool', 'parse_uri',
     'Fire', 'Ip2Region', 'Singleton', 'JSONEncoder',
     'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
     'Email', 'AioEmail', 'Queue', 'AioQueue',
