@@ -7,8 +7,11 @@ Last modified: 2018-01-05 11:24:17
 '''
 import asyncio
 import os
+import re
 import time
+from urllib.parse import parse_qs
 from urllib.parse import quote_plus
+from urllib.parse import unquote_plus
 
 import aiomysql
 import aredis
@@ -29,7 +32,42 @@ from motor.metaprogramming import unwrap_kwargs_session
 
 from .utils import Dict
 
-__all__ = ['Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient', 'Mysql', 'AioMysql']
+__all__ = ['Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient', 'Mysql', 'AioMysql', 'parse_uri']
+
+
+def parse_uri(uri):
+    pattern = re.compile(r'''
+        (?P<schema>[\w\+]+)://
+        (?:
+            (?P<user>[^:/]*)
+            (?::(?P<passwd>[^/]*))?
+        @)?
+        (?:
+            (?P<host>[^/:]*)
+            (?::(?P<port>[^/]*))?
+        )?
+        (?:/(?P<db>\w*))?
+        (?:\?(?P<extra>.*))?
+        ''', re.X)
+
+    m = pattern.match(uri)
+    assert m is not None, 'Could not parse rfc1738 URL'
+    kwargs = Dict()
+    for k, v in m.groupdict().items():
+        if v is None:
+            continue
+        if k == 'extra':
+            ret = parse_qs(v)
+            ret = {_k: _v[0] if len(_v) == 1 else _v for _k, _v in ret.items()}
+            kwargs.update(ret)
+        elif k == 'port':
+            kwargs[k] = int(v)
+        else:
+            kwargs[k] = unquote_plus(v)
+
+    if kwargs.schema == 'redis' and kwargs.db:
+        kwargs.db = int(kwargs.db)
+    return kwargs
 
 
 class Collection(pymongo.collection.Collection):
@@ -271,15 +309,23 @@ class AioRedis(aredis.StrictRedis):
 
 class Mysql:
 
-    def __init__(self, host='localhost', port=3306, user=None, password='', db=None,
-                 time_zone='+08:00', max_idle_time=7 * 3600, charset='utf8',
+    def __init__(self, time_zone='+08:00', max_idle_time=7 * 3600, charset='utf8',
                  sql_mode='TRADITIONAL', autocommit=True, **kwargs):
+        if any([key in kwargs for key in ['host', 'port', 'password', 'db']]):
+            host = kwargs.pop('host', 'localhost')
+            port = kwargs.pop('port', 3306)
+            user = kwargs.pop('user', None)
+            password = kwargs.pop('password', '')
+            kwargs.update(dict(host=host, port=port, user=user, password=password))
+        elif kwargs.get('uri'):
+            uri = kwargs.pop('uri')
+            kwargs.update(parse_uri(uri))
+        elif os.environ.get('MYSQL_URI'):
+            uri = os.environ['REDIS_URI']
+            kwargs.update(parse_uri(uri))
+
         init_command = f'SET time_zone = "{time_zone}"'
-        if host.find(':') >= 0:
-            pair = host.split(':')
-            host, port = pair[0], int(pair[1])
-        self._args = dict(host=host, port=port, user=user, password=password,
-                          db=db, charset=charset, init_command=init_command,
+        self._args = dict(charset=charset, init_command=init_command,
                           sql_mode=sql_mode, autocommit=autocommit, **kwargs)
         self._conn = None
         self._pool = None
